==> nextcloud-28.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/circles/l10n/gl.js <==
OC.L10N.register(
    "circles",
    {
    "You deleted {circle}" : "Vde. eliminou {circle}",
    "{author} deleted {circle}" : "{author} eliminou {circle}",
    "You joined {circle}" : "Vde. uniuse a {circle}",
    "{member} joined {circle}" : "{member} uniuse a {circle}",
    "You accepted the invitation to join {circle}" : "Vde. aceptou o convite para unirse a {circle}",
    "{member} accepted the invitation to join {circle}" : "{member} aceptou o convite para unirse a {circle}",
    "You added {member} as member to {circle}" : "Vde. engadiu a {member} como participante en {circle}",
    "You have been added as member to {circle} by {author}" : "{author} fíxoo membro do grupo {circle}",
    "{member} has been added as member to {circle} by {author}" : "{author} engadiu a {member} como membro de {circle}",
    "You added {external} to {circle}" : "Vde. engadiu a {external} a {circle}",
    "{external} has been added to {circle} by {author}" : "{external} foi engadido a {circle} por {author}",
    "You accepted {member}'s request to join {circle}" : "Vde. aceptou a solicitude de {member} para unirse a {circle}",
    "Your request to join {circle} has been accepted by {author}" : "A súa solicitude para unirse a {circle} foi aceptada por {author}",
    "{member}'s request to join {circle} has been accepted by {author}" : "A solicitude de {member} para unirse a {circle} foi aceptada por {author}",
    "You left {circle}" : "Vde. abandonou {circle}",
    "{member} left {circle}" : "{member} abandonou {circle}",
    "You declined the invitation to join {circle}" : "Declinou o convite para unirse a {circle}",
    "{member} declined an invitation to join {circle}" : "{member} declinou o convite para unirse a {circe}",
    "You cancelled your request to join {circle}" : "Cancelou a súa solicitude para unirse a {circle}",
    "You removed {member} from {circle}" : "Vde. retirou a {member} de {circle}",
    "You have been removed from {circle} by {author}" : "Vde. foi retirado de {circle} por {author}",
    "{member} has been removed from {circle} by {author}" : "{author} foi retirado de {circle} por {author}",
    "You removed {external} from {circle}" : "Vde. retirou a {external} de {circle}",
    "{external} has been removed from {circle} by {author}" : "{external} foi retirado de {circle} por {author}",
    "You cancelled {member}'s invitation to join {circle}" : "Vde. cancelou o convite de {member} para unirse a {circle}",
    "Your invitation to join {circle} has been cancelled by {author}" : "{author} cancelou o seu convite para unirse a {circle}",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} cancelou o convite de {member} para unirse a {circle}",
    "You dismissed {member}'s request to join {circle}" : "Vde. rexeitou a solicitude de {member} para unirse a {circle}",
    "Your request to join {circle} has been dismissed by {author}" : "A súa solicitude para unirse a {circle} foi rexeitada por {author}",
    "{member}'s request to join {circle} has been dismissed by {author}" : "A solicitude de {member} para unirse a {circle} foi rexeitada por {author}",
    "You invited {member} to join {circle}" : "Vde. convidou a {member} para unirse a {circle}",
    "You have been invited to join {circle} by {author}" : "Vde. foi convidado para unirse a {circle} por {author}",
    "{member} has been invited to join {circle} by {author}" : "{author} foi convidado para unirse a {circle} por {author}",
    "You changed {member}'s level in {circle} to %1$s" : "Vde. cambiou o nivel de {member} en {circle} a %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} cambiou o seu nivel en {circle} a %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} cambiou o nivel de {member} en {circle} a %1$s",
    "You sent a request to join {circle}" : "Vde. enviou unha solicitude para unirse a {circle}",
    "{member} sent a request to join {circle}" : "{member} enviou unha solicitude para unirse a {circle}",
    "You are the new owner of {circle}" : "Vde. é o novo propietario de {circle}",
    "{member} is the new owner of {circle}" : "{member} é o novo propietario de {circle}",
    "Shared to Circles" : "Compartido con Círculos",
    "Single" : "Individual",
    "Personal" : "Persoal",
    "System" : "Sistema",
    "Visible" : "Visíbel",
    "Open" : "Abrir",
    "Invite" : "Convidar",
    "Friends" : "Amigo/a",
    "Password protected" : "Protexido con contrasinal",
    "No Owner" : "Sen propietario",
    "Hidden" : "Agochada",
    "Backend" : "Infraestrutura",
    "Local" : "Local",
    "Root" : "Raíz",
    "Federated" : "Federado",
    "Mount point" : "Punto de montaxe",
    "Nextcloud Account" : "Conta de Nextcloud",
    "Nextcloud Group" : "Grupo de Nextcloud",
    "Email address" : "Enderezo de correo",
    "Contact" : "Contacto",
    "Circle" : "Círculo",
    "Nextcloud App" : "Aplicación Nextcloud",
    "Member" : "Membro",
    "Moderator" : "Moderador",
    "Admin" : "Administración",
    "Owner" : "Propietario",
    "%s shared »%s« with you." : "%s compartiu «%s» con Vde.",
    "%s shared »%s« with \"%s\"." : "%s compartiu «%s» con «%s».",
    "%s on %s" : "%s en %s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s compartiu «%2$s» con Vde.\nXa debería ter recibido un correo aparte cunha ligazón para acceder a el.\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s compartiu «%2$s» con Vde. Xa debería ter recibido un correo aparte cunha ligazón para acceder a el.",
    "Password to access »%1$s« shared to you by %2$s" : "O contrasinal para acceder a «%1$s» foi compartido con Vde. por %2$s",
    "Password to access »%s«" : "Contrasinal para acceder a «%s»",
    "It is protected with the following password:" : "Está protexido co seguinte contrasinal: ",
    "%1$s via %2$s" : "%1$s mediante %2$s",
    "Click the button below to open it." : "Prema no botón de embaixo para abrilo.",
    "Open »%s«" : "Abrir «%s»",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s compartiu varios ficheiros con Vde.\nXa debería ter recibido un correo aparte cunha ligazón para acceder a eles.\n",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$s compartiu varios ficheiros con Vde. Xa debería ter recibido un correo aparte cunha ligazón para acceder a eles.",
    "Password to access files shared to you by %1$s" : "O contrasinal para acceder aos ficheiros compartidos con Vde. por %1$s",
    "Password to access files" : "Contrasinal para acceder aos ficheiros",
    "%s shared multiple files with \"%s\"." : "%s compartiu varios ficheiros con «%s».",
    "%s shared multiple files with you." : "%s compartiu varios ficheiros con Vde.",
    "Boot up" : "Arrincar",
    "Nextcloud Initialization" : "Inicialización de Nextcloud",
    "Circles App Initialization" : "Inicialización da aplicación Círculos",
    "Fresh installation status" : "Estado da nova instalación",
    "Building Local Database" : "Creando a base de datos local",
    "Testing Basic Circle Creation" : "Proba básica de creación de círculos",
    "Adding local users and moderators" : "Engadindo usuarios e moderadores locais",
    "Files" : "Ficheiros",
    "This feature is not available for personal circles" : "Esta característica non está dispoñíbel para círculos persoais",
    "This member is not a moderator" : "Este membro non é un moderador",
    "Insufficient privileges" : "Non ten privilexios abondo",
    "This member does not exist" : "Non existe este membro",
    "Level cannot be changed for this type of member" : "Non é posíbel cambiar o nivel para este tipo de membro",
    "You are already a member of this circle" : "Vde. xa é membro deste círculo",
    "You have been blocked from this circle" : "Vde. foi bloqueado neste círculo",
    "The account is already a member of this circle" : "A conta xa é membro deste círculo",
    "The account has already been invited into this circle" : "A conta xa foi convidada a este círculo",
    "You are now a member of the Circle \"%2$s\"" : "Vde. agora é participante no círculo «%2$s»",
    "You have been invited by %1$s into the Circle \"%2$s\"" : "Vde. foi convidado por %1$s ao círculo «%2$s»",
    "%1$s sent a request to be a member of the Circle \"%2$s\"" : "%1$s enviou unha solicitude para ser participante no círculo «%2$s»",
    "Accept" : "Aceptar",
    "Refuse" : "Rexeitar",
    "Leave the circle" : "Abandonar o círculo",
    "%s" : "%s",
    "%s owned by %s" : "%s propiedade de %s",
    "%s shared a file with \"%s\"." : "%s compartiu un ficheiro con «%s».",
    "%s shared a file with you." : "%s compartiu un ficheiro con Vde.",
    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s compartiu algún contido con Vde.\nXa debería ter recibido un correo aparte cunha ligazón para acceder a el.\n",
    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s compartiu algún contido con Vde. Xa debería ter recibido un correo aparte cunha ligazón para acceder a el.",
    "Password to access content shared with you by %1$s" : "Contrasinal para acceder ao contido compartido con Vde. por %1$s",
    "Password to access content" : "Contrasinal para acceder ao contido",
    "Bring cloud-users closer together." : "Acerque aos usuarios das nubes.",
    "No files in here" : "Aquí non hai ficheiros",
    "No entries found in this folder" : "Non se atoparon entradas neste cartafol",
    "Name" : "Nome",
    "Size" : "Tamaño",
    "Modified" : "Modificado",
    "Circles" : "Círculos",
    "Circles' files" : "Ficheiros dos círculos",
    "Select circles to filter by" : "Seleccionar círculos polos que filtrar",
    "No circles found" : "Non se atoparon círculos",
    "Please select circles to filter by" : "Seleccione os círculos polos que filtrar",
    "No files found for the selected circles" : "Non se atoparon ficheiros para os círculos seleccionados",
    "You created the circle {circle}" : "Vde. creou o círculo {circle}",
    "{author} created the circle {circle}" : "{author} creou o círculo {circle}",
    "On events happening in a <strong>Circle</strong> of which you are a member" : "En eventos que ocorren nun <strong>círculo</strong> do que  Vde. é membro",
    "Any important event in a <strong>Circle</strong> you are moderating" : "Calquera evento importante nun Círculo do que Vde. é o moderador",
    "On global events happening in any <strong>Circle</strong>" : "En eventos globais que suceden en calquera <strong>círculo</strong>",
    "Join Request" : "Solicitude para unirse",
    "Password Protected" : "Protexido por contrasinal",
    "Circle Invite" : "Convite ao círculo",
    "Email Address" : "Enderezo de correo-e",
    "Initialisation Nextcloud" : "Inicialización de Nextcloud",
    "Initialisation Circles App" : "Inicialización da aplicación Círculos",
    "Circle not found" : "Non se atopou o círculo",
    "Circle not found " : "Non se atopou o círculo",
    "This account is already a member of the circle" : "Esta conta xa é membro do círculo",
    "Federated link not found" : "Non se atopou a ligazón federada",
    "The circle is not federated" : "Este círculo non está federado",
    "You cannot join this circle" : "Vde. non pode unirse a este círculo",
    "This member is the owner of the circle" : "Este membro é o propietario do círculo",
    "%s (Circle owned by %s)" : "%s (Círculo propiedade de %s)",
    "Personal Circle" : "Círculo persoal",
    "You need a specify a type of circle" : "Ten que especificar o tipo de círculo",
    "A circle with that name exists" : "Xa existe un círculo con ese nome.",
    "This member is not the owner of the circle" : "Este membro non é o propietario do círculo",
    "This member is not an admin of the circle" : "Este membro non é o administrador do círculo",
    "Group contains too many members" : "O grupo contén demasiados membros",
    "This group does not exist" : "Non existe este grupo",
    "This group is already linked to the circle" : "Este grupo xa está ligado co círculo",
    "You cannot edit level in a personal circle" : "Vde. no pode editar o nivel nun círculo persoal",
    "Group cannot be set as owner of a circle" : "O grupo non se pode estabelecer como propietario dun círculo",
    "now" : "agora",
    "This account does not exist" : "Esta conta non existe",
    "Email format is not valid" : "O formato do correo non é válido",
    "This contact is not available" : "Este contacto non está dispoñíbel",
    "You have no permission to create a new circle" : "Non te permisos para crear un novo círculo",
    "This item is already shared with this circle" : "Este elemento xa está compartido con este círculo",
    "Circles allows people to create their own groups of people/colleagues/friends.\nThose groups of people (or \"circles\") can then be used by any other app for sharing purpose." : "Círculos permítelle ás persoas crear os seus propios grupos de persoas/colegas/amigos.\nEses grupos de persoas (ou «círculos») poden ser usados por calquera outra aplicación para compartir."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-31.0.8-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/circles/l10n/gl.js <==
OC.L10N.register(
    "circles",
    {
    "Teams" : "Equipos",
    "You created the team {circle}" : "Vde. creou o equipo {circle}",
    "{author} created the team {circle}" : "{author} creou o equipo {circle}",
    "You deleted {circle}" : "Vde. eliminou {circle}",
    "{author} deleted {circle}" : "{author} eliminou {circle}",
    "You made {member} join {circle}" : "Vde. fixo que {member} se unise a {circle}",
    "{author} made {member} join {circle}" : "{author} fixo que {member} se unise a {circle}",
    "You added team {member} as member to {circle}" : "Vde. engadiu o equipo {member} como participante en {circle}",
    "{author} added team {member} as member to {circle}" : "{author} engadiu o equipo {member} como participante en {circle}",
    "You made {member} leave {circle}" : "Vde. fixo que {member} deixase {circle}",
    "{author} made {member} leave {circle}" : "{author} fixo que {member} deixase {circle}",
    "You removed {member} from {circle}" : "Vde. retirou a {member} de {circle}",
    "{author} removed {member} from {circle}" : "{author} retirou a {member} de {circle}",
    "You joined {circle}" : "Vde. uniuse a {circle}",
    "{member} joined {circle}" : "{member} uniuse a {circle}",
    "You accepted the invitation to join {circle}" : "Vde. aceptou o convite para unirse a {circle}",
    "{member} accepted the invitation to join {circle}" : "{member} aceptou o convite para unirse a {circle}",
    "You added {member} as member to {circle}" : "Vde. engadiu a {member} como participante en {circle}",
    "You have been added as member to {circle} by {author}" : "{author} fíxoo membro do grupo {circle}",
    "{member} has been added as member to {circle} by {author}" : "{author} engadiu a {member} como membro de {circle}",
    "You added {external} to {circle}" : "Vde. engadiu a {external} a {circle}",
    "{external} has been added to {circle} by {author}" : "{external} foi engadido a {circle} por {author}",
    "You accepted {member}'s request to join {circle}" : "Vde. aceptou a solicitude de {member} para unirse a {circle}",
    "Your request to join {circle} has been accepted by {author}" : "A súa solicitude para unirse a {circle} foi aceptada por {author}",
    "{member}'s request to join {circle} has been accepted by {author}" : "A solicitude de {member} para unirse a {circle} foi aceptada por {author}",
    "You left {circle}" : "Vde. abandonou {circle}",
    "{member} left {circle}" : "{member} abandonou {circle}",
    "You declined the invitation to join {circle}" : "Declinou o convite para unirse a {circle}",
    "{member} declined an invitation to join {circle}" : "{member} declinou o convite para unirse a {circe}",
    "You cancelled your request to join {circle}" : "Vde. cancelou a súa solicitude para unirse a {circle}",
    "{member} cancelled a request to join {circle}" : "{member} cancelou unha solicitude para unirse a {circle}",
    "You have been removed from {circle} by {author}" : "Vde. foi retirado de {circle} por {author}",
    "{member} has been removed from {circle} by {author}" : "{author} foi retirado de {circle} por {author}",
    "You removed {external} from {circle}" : "Vde. retirou a {external} de {circle}",
    "{external} has been removed from {circle} by {author}" : "{external} foi retirado de {circle} por {author}",
    "You cancelled {member}'s invitation to join {circle}" : "Vde. cancelou o convite de {member} para unirse a {circle}",
    "Your invitation to join {circle} has been cancelled by {author}" : "{author} cancelou o seu convite para unirse a {circle}",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} cancelou o convite de {member} para unirse a {circle}",
    "You dismissed {member}'s request to join {circle}" : "Vde. rexeitou a solicitude de {member} para unirse a {circle}",
    "Your request to join {circle} has been dismissed by {author}" : "A súa solicitude para unirse a {circle} foi rexeitada por {author}",
    "{member}'s request to join {circle} has been dismissed by {author}" : "A solicitude de {member} para unirse a {circle} foi rexeitada por {author}",
    "You invited {member} to join {circle}" : "Vde. convidou a {member} para unirse a {circle}",
    "You have been invited to join {circle} by {author}" : "Vde. foi convidado para unirse a {circle} por {author}",
    "{member} has been invited to join {circle} by {author}" : "{author} foi convidado para unirse a {circle} por {author}",
    "You changed {member}'s level in {circle} to %1$s" : "Vde. cambiou o nivel de {member} en {circle} a %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} cambiou o seu nivel en {circle} a %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} cambiou o nivel de {member} en {circle} a %1$s",
    "You sent a request to join {circle}" : "Vde. enviou unha solicitude para unirse a {circle}",
    "{member} sent a request to join {circle}" : "{member} enviou unha solicitude para unirse a {circle}",
    "You are the new owner of {circle}" : "Vde. é o novo propietario de {circle}",
    "{member} is the new owner of {circle}" : "{member} é o novo propietario de {circle}",
    "On events happening in a <strong>team</strong> of which you are a member" : "En eventos que ocorren nun <strong>equípo</strong> do que  Vde. é membro",
    "Any important event in a <strong>team</strong> you are moderating" : "Calquera evento importante nun <strong>equipo</strong> do que Vde. é o moderador",
    "On global events happening in any <strong>team</strong>" : "En eventos globais que ocorren en calquera <strong>equipo</strong>",
    "Single" : "Individual",
    "Personal" : "Persoal",
    "System" : "Sistema",
    "Visible" : "Visíbel",
    "Open" : "Abrir",
    "Invite" : "Convidar",
    "Join request" : "Solicitude para unirse",
    "Friends" : "Amigo/a",
    "Password protected" : "Protexido con contrasinal",
    "No Owner" : "Sen propietario",
    "Hidden" : "Agochada",
    "Backend" : "Infraestrutura",
    "Local" : "Local",
    "Root" : "Raíz",
    "Team invite" : "Convite do equipo",
    "Federated" : "Federado",
    "Mount point" : "Punto de montaxe",
    "Nextcloud Account" : "Conta de Nextcloud",
    "Nextcloud Group" : "Grupo de Nextcloud",
    "Email address" : "Enderezo de correo",
    "Contact" : "Contacto",
    "Circle" : "Círculo",
    "Nextcloud App" : "Aplicación Nextcloud",
    "Member" : "Membro",
    "Moderator" : "Moderador",
    "Admin" : "Administración",
    "Owner" : "Propietario",
    "%s shared »%s« with you." : "%s compartiu «%s» con Vde.",
    "%s shared »%s« with \"%s\"." : "%s compartiu «%s» con «%s».",
    "%s on %s" : "%s en %s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s compartiu «%2$s» con Vde.\nXa debería ter recibido un correo aparte cunha ligazón para acceder a el.\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s compartiu «%2$s» con Vde. Xa debería ter recibido un correo aparte cunha ligazón para acceder a el.",
    "Password to access »%1$s« shared to you by %2$s" : "O contrasinal para acceder a «%1$s» foi compartido con Vde. por %2$s",
    "Password to access »%s«" : "Contrasinal para acceder a «%s»",
    "It is protected with the following password:" : "Está protexido co seguinte contrasinal: ",
    "%1$s via %2$s" : "%1$s mediante %2$s",
    "Click the button below to open it." : "Prema no botón de embaixo para abrilo.",
    "Open »%s«" : "Abrir «%s»",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s compartiu varios ficheiros con Vde.\nXa debería ter recibido un correo aparte cunha ligazón para acceder a eles.\n",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$s compartiu varios ficheiros con Vde. Xa debería ter recibido un correo aparte cunha ligazón para acceder a eles.",
    "Password to access files shared to you by %1$s" : "O contrasinal para acceder aos ficheiros compartidos con Vde. por %1$s",
    "Password to access files" : "Contrasinal para acceder aos ficheiros",
    "%s shared multiple files with \"%s\"." : "%s compartiu varios ficheiros con «%s».",
    "%s shared multiple files with you." : "%s compartiu varios ficheiros con Vde.",
    "Boot up" : "Arrancar",
    "Nextcloud Initialization" : "Inicialización de Nextcloud",
    "Circles App Initialization" : "Inicialización da aplicación Círculos",
    "Fresh installation status" : "Estado da nova instalación",
    "Building Local Database" : "Creando a base de datos local",
    "Testing Basic Circle Creation" : "Proba básica de creación de círculos",
    "Adding local users and moderators" : "Engadindo usuarios e moderadores locais",
    "Show all teams" : "Amosar todos os equipos",
    "Create a new team" : "Crear un novo equipo",
    "Files" : "Ficheiros",
    "This feature is not available for personal circles" : "Esta característica non está dispoñíbel para círculos persoais",
    "The team is not federated" : "O equipo non está federado",
    "You cannot join this team" : "Vde. non pode unirse a este equipo",
    "This member is not a moderator" : "Este membro non é un moderador",
    "Insufficient privileges" : "Non ten privilexios abondo",
    "This member does not exist" : "Non existe este membro",
    "This member is the owner of the team" : "Este membro é o propietario do equipo",
    "Level cannot be changed for this type of member" : "Non é posíbel cambiar o nivel para este tipo de membro",
    "You are already a member of this circle" : "Vde. xa é membro deste círculo",
    "You have been blocked from this circle" : "Vde. foi bloqueado neste círculo",
    "The account is already a member of this circle" : "A conta xa é membro deste círculo",
    "The account has already been invited into this circle" : "A conta xa foi convidada a este círculo",
    "%s (Team owned by %s)" : "%s (Equipo propiedade de %s)",
    "You are now a member of the Team \"%2$s\"" : "Vde. agora é participante no equipo «%2$s»",
    "You have been invited by %1$s into the Team \"%2$s\"" : "Vde. foi convidado por %1$s ao equipo «%2$s»",
    "%1$s sent a request to be a member of the Team \"%2$s\"" : "%1$s enviou unha solicitude para ser participante no equipo «%2$s»",
    "Accept" : "Aceptar",
    "Refuse" : "Rexeitar",
    "Leave the team" : "Deixar o equipo",
    "%s" : "%s",
    "Personal team" : "Equipo persoal",
    "%s owned by %s" : "%s propiedade de %s",
    "You have no permission to create a new team" : "Vde. non ten permiso para crear un novo equipo",
    "%s shared a file with \"%s\"." : "%s compartiu un ficheiro con «%s».",
    "%s shared a file with you." : "%s compartiu un ficheiro con Vde.",
    "Open %s" : "Abrir %s",
    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s compartiu algún contido con Vde.\nXa debería ter recibido un correo aparte cunha ligazón para acceder a el.\n",
    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s compartiu algún contido con Vde. Xa debería ter recibido un correo aparte cunha ligazón para acceder a el.",
    "Password to access content shared with you by %1$s" : "Contrasinal para acceder ao contido compartido con Vde. por %1$s",
    "Password to access content" : "Contrasinal para acceder ao contido",
    "This item is already shared with this team" : "Este elemento xa está compartido con este equipo",
    "Bring cloud-users closer together." : "Acercar aos usuarios da nube.",
    "Teams allows people to create their own groups of people/colleagues/friends.\nThose groups of people can then be used by any other app for sharing purpose." : "Os equipos permítelle ás persoas crear os seus propios grupos de persoas/colegas/amigos.\nEses grupos de persoas (ou «círculos») poden ser usados por calquera outra aplicación para compartir.",
    "No files in here" : "Aquí non hai ficheiros",
    "No entries found in this folder" : "Non se atopou ningunha entrada neste cartafol",
    "Name" : "Nome",
    "Size" : "Tamaño",
    "Modified" : "Modificado",
    "Teams' files" : "Ficheiros dos equipos",
    "Select team to filter by" : "Seleccione o equipo polo que filtrar",
    "No teams found" : "Non se atopou ningún equipo",
    "Please select teams to filter by" : "Seleccione os equipos polos que filtrar",
    "No files found for the selected teams" : "Non se atopou ningún ficheiro para os equipos seleccionados",
    "Shared to Circles" : "Compartido con Círculos"
},
"nplurals=2; plural=(n != 1);");
